@@ -38,7 +38,7 @@ var override = require('../utils/override');
 //   Puts the shorthand together from its components.
 //
 var configuration = {
-  'animation': {
+  animation: {
     canOverride: canOverride.generic.components([
       canOverride.generic.time,
       canOverride.generic.timingFunction,
@@ -200,7 +200,7 @@ var configuration = {
       '-webkit-'
     ]
   },
-  'background': {
+  background: {
     canOverride: canOverride.generic.components([
       canOverride.generic.image,
       canOverride.property.backgroundPosition,
@@ -341,7 +341,7 @@ var configuration = {
       valueOptimizers.zero
     ]
   },
-  'bottom': {
+  bottom: {
     canOverride: canOverride.property.bottom,
     defaultValue: 'auto',
     valueOptimizers: [
@@ -352,7 +352,7 @@ var configuration = {
       valueOptimizers.zero
     ]
   },
-  'border': {
+  border: {
     breakUp: breakUp.border,
     canOverride: canOverride.generic.components([
       canOverride.generic.unit,
@@ -829,11 +829,11 @@ var configuration = {
       '-webkit-'
     ]
   },
-  'clear': {
+  clear: {
     canOverride: canOverride.property.clear,
     defaultValue: 'none'
   },
-  'clip': {
+  clip: {
     valueOptimizers: [
       valueOptimizers.whiteSpace,
       valueOptimizers.fraction,
@@ -842,7 +842,7 @@ var configuration = {
       valueOptimizers.zero
     ]
   },
-  'color': {
+  color: {
     canOverride: canOverride.generic.color,
     defaultValue: 'transparent',
     shortestValue: 'red',
@@ -861,24 +861,22 @@ var configuration = {
       valueOptimizers.zero
     ]
   },
-  'cursor': {
+  cursor: {
     canOverride: canOverride.property.cursor,
     defaultValue: 'auto'
   },
-  'display': {
-    canOverride: canOverride.property.display,
-  },
-  'filter': {
+  display: { canOverride: canOverride.property.display },
+  filter: {
     propertyOptimizer: propertyOptimizers.filter,
     valueOptimizers: [
       valueOptimizers.fraction
     ]
   },
-  'float': {
+  float: {
     canOverride: canOverride.property.float,
     defaultValue: 'none'
   },
-  'font': {
+  font: {
     breakUp: breakUp.font,
     canOverride: canOverride.generic.components([
       canOverride.property.fontStyle,
@@ -937,7 +935,7 @@ var configuration = {
     propertyOptimizer: propertyOptimizers.fontWeight,
     shortestValue: '400'
   },
-  'gap': {
+  gap: {
     valueOptimizers: [
       valueOptimizers.whiteSpace,
       valueOptimizers.fraction,
@@ -946,7 +944,7 @@ var configuration = {
       valueOptimizers.zero
     ]
   },
-  'height': {
+  height: {
     canOverride: canOverride.generic.unit,
     defaultValue: 'auto',
     shortestValue: '0',
@@ -958,7 +956,7 @@ var configuration = {
       valueOptimizers.zero
     ]
   },
-  'left': {
+  left: {
     canOverride: canOverride.property.left,
     defaultValue: 'auto',
     valueOptimizers: [
@@ -1001,14 +999,14 @@ var configuration = {
     shortestValue: 'none',
     shorthand: true
   },
-  'list-style-image' : {
+  'list-style-image': {
     canOverride: canOverride.generic.image,
     componentOf: [
       'list-style'
     ],
     defaultValue: 'none'
   },
-  'list-style-position' : {
+  'list-style-position': {
     canOverride: canOverride.property.listStylePosition,
     componentOf: [
       'list-style'
@@ -1016,7 +1014,7 @@ var configuration = {
     defaultValue: 'outside',
     shortestValue: 'inside'
   },
-  'list-style-type' : {
+  'list-style-type': {
     canOverride: canOverride.property.listStyleType,
     componentOf: [
       'list-style'
@@ -1027,7 +1025,7 @@ var configuration = {
     defaultValue: 'decimal|disc',
     shortestValue: 'none'
   },
-  'margin': {
+  margin: {
     breakUp: breakUp.fourValues,
     canOverride: canOverride.generic.components([
       canOverride.generic.unit,
@@ -1183,13 +1181,13 @@ var configuration = {
       valueOptimizers.zero
     ]
   },
-  'opacity': {
+  opacity: {
     valueOptimizers: [
       valueOptimizers.fraction,
       valueOptimizers.precision
     ]
   },
-  'outline': {
+  outline: {
     canOverride: canOverride.generic.components([
       canOverride.generic.color,
       canOverride.property.outlineStyle,
@@ -1248,7 +1246,7 @@ var configuration = {
       valueOptimizers.zero
     ]
   },
-  'overflow': {
+  overflow: {
     canOverride: canOverride.property.overflow,
     defaultValue: 'visible'
   },
@@ -1260,7 +1258,7 @@ var configuration = {
     canOverride: canOverride.property.overflow,
     defaultValue: 'visible'
   },
-  'padding': {
+  padding: {
     breakUp: breakUp.fourValues,
     canOverride: canOverride.generic.components([
       canOverride.generic.unit,
@@ -1326,7 +1324,7 @@ var configuration = {
     defaultValue: '0',
     oppositeTo: 'padding-left',
     propertyOptimizer: propertyOptimizers.padding,
-        valueOptimizers: [
+    valueOptimizers: [
       valueOptimizers.whiteSpace,
       valueOptimizers.fraction,
       valueOptimizers.precision,
@@ -1350,11 +1348,11 @@ var configuration = {
       valueOptimizers.zero
     ]
   },
-  'position': {
+  position: {
     canOverride: canOverride.property.position,
     defaultValue: 'static'
   },
-  'right': {
+  right: {
     canOverride: canOverride.property.right,
     defaultValue: 'auto',
     valueOptimizers: [
@@ -1374,7 +1372,7 @@ var configuration = {
       valueOptimizers.zero
     ]
   },
-  'src': {
+  src: {
     valueOptimizers: [
       valueOptimizers.urlWhiteSpace,
       valueOptimizers.urlPrefix,
@@ -1423,7 +1421,7 @@ var configuration = {
       valueOptimizers.color
     ]
   },
-  'top': {
+  top: {
     canOverride: canOverride.property.top,
     defaultValue: 'auto',
     valueOptimizers: [
@@ -1434,7 +1432,7 @@ var configuration = {
       valueOptimizers.zero
     ]
   },
-  'transform': {
+  transform: {
     canOverride: canOverride.property.transform,
     valueOptimizers: [
       valueOptimizers.whiteSpace,
@@ -1451,7 +1449,7 @@ var configuration = {
       '-webkit-'
     ]
   },
-  'transition': {
+  transition: {
     breakUp: breakUp.multiplex(breakUp.transition),
     canOverride: canOverride.generic.components([
       canOverride.property.transitionProperty,
@@ -1555,7 +1553,7 @@ var configuration = {
       valueOptimizers.zero
     ]
   },
-  'visibility': {
+  visibility: {
     canOverride: canOverride.property.visibility,
     defaultValue: 'visible'
   },
@@ -1578,7 +1576,7 @@ var configuration = {
     canOverride: canOverride.property.whiteSpace,
     defaultValue: 'normal'
   },
-  'width': {
+  width: {
     canOverride: canOverride.generic.unit,
     defaultValue: 'auto',
     shortestValue: '0',
@@ -1603,13 +1601,13 @@ function cloneDescriptor(propertyName, prefix) {
   var clonedDescriptor = override(configuration[propertyName], {});
 
   if ('componentOf' in clonedDescriptor) {
-    clonedDescriptor.componentOf = clonedDescriptor.componentOf.map(function (shorthandName) {
+    clonedDescriptor.componentOf = clonedDescriptor.componentOf.map(function(shorthandName) {
       return prefix + shorthandName;
     });
   }
 
   if ('components' in clonedDescriptor) {
-    clonedDescriptor.components = clonedDescriptor.components.map(function (longhandName) {
+    clonedDescriptor.components = clonedDescriptor.components.map(function(longhandName) {
       return prefix + longhandName;
     });
   }
@@ -1621,8 +1619,6 @@ function cloneDescriptor(propertyName, prefix) {
   return clonedDescriptor;
 }
 
-var vendorPrefixedConfiguration = {};
-
 for (var propertyName in configuration) {
   var descriptor = configuration[propertyName];
 
