@@ -1,7 +1,16 @@
-var systemLineBreak = require('os').EOL;
-
 var override = require('../utils/override');
 
+function getSystemLineBreak() {
+  var systemLineBreak = '\n';
+  try {
+    var os = require('os');
+    systemLineBreak = os.EOL;
+  } catch (_) {
+    // no op
+  }
+  return systemLineBreak;
+}
+
 var Breaks = {
   AfterAtRule: 'afterAtRule',
   AfterBlockBegins: 'afterBlockBegins',
@@ -17,7 +26,7 @@ var Breaks = {
 var BreakWith = {
   CarriageReturnLineFeed: '\r\n',
   LineFeed: '\n',
-  System: systemLineBreak
+  System: getSystemLineBreak()
 };
 
 var IndentWith = {
@@ -193,7 +202,7 @@ function mapBreakWith(value) {
   case BreakWith.LineFeed:
     return BreakWith.LineFeed;
   default:
-    return systemLineBreak;
+    return BreakWith.System;
   }
 }
 
