@@ -440,6 +440,25 @@ vows.describe('source-map')
         };
         assert.deepEqual(minified.sourceMap._mappings._array[2], mapping);
       }
+    },
+    'preserved CSS fragment': {
+      'topic': function () {
+        return new CleanCSS({ level: 2, sourceMap: true }).minify('/* clean-css ignore:start */a { margin: 0px; }/* clean-css ignore:end */');
+      },
+      'has 1 mapping': function (minified) {
+        assert.lengthOf(minified.sourceMap._mappings._array, 1);
+      },
+      'has all preserved content mapping': function (minified) {
+        var mapping = {
+          generatedLine: 1,
+          generatedColumn: 0,
+          originalLine: 1,
+          originalColumn: 28,
+          source: '$stdin',
+          name: null
+        };
+        assert.deepEqual(minified.sourceMap._mappings._array[0], mapping);
+      }
     }
   })
   .addBatch({
@@ -609,7 +628,7 @@ vows.describe('source-map')
     },
     'input map from source with rebaseTo': {
       'topic': function () {
-        return new CleanCSS({ level: 2, sourceMap: true, rebaseTo: './test/fixtures' }).minify('div > a {\n  color: red;\n}/*# sourceMappingURL=' + inputMapPath + ' */');
+        return new CleanCSS({ level: 2, sourceMap: true, rebase: true, rebaseTo: './test/fixtures' }).minify('div > a {\n  color: red;\n}/*# sourceMappingURL=' + inputMapPath + ' */');
       },
       'has 3 mappings': function (minified) {
         assert.lengthOf(minified.sourceMap._mappings._array, 3);
@@ -649,15 +668,15 @@ vows.describe('source-map')
       }
     },
     'input map as inlined data URI with implicit charset us-ascii, not base64, no content-type': inlineDataUriContext('data:,' + escape(inputMap)),
-    'input map as inlined data URI with implicit charset us-ascii, base64': inlineDataUriContext('data:application/json;base64,' + new Buffer(inputMap, 'ascii').toString('base64')),
+    'input map as inlined data URI with implicit charset us-ascii, base64': inlineDataUriContext('data:application/json;base64,' + Buffer.from(inputMap, 'ascii').toString('base64')),
     'input map as inlined data URI with implicit charset us-ascii, not base64': inlineDataUriContext('data:application/json,' + escape(inputMap)),
-    'input map as inlined data URI with charset utf-8, base64': inlineDataUriContext('data:application/json;charset=utf-8;base64,' + new Buffer(inputMap, 'utf8').toString('base64')),
-    'input map as inlined data URI with charset utf-8, not base64': inlineDataUriContext('data:application/json;charset=utf-8,' + escape(String.fromCharCode.apply(String, new Buffer(inputMap, 'utf8')))),
-    'input map as inlined data URI with explicit charset us-ascii, base64': inlineDataUriContext('data:application/json;charset=us-ascii;base64,' + new Buffer(inputMap, 'ascii').toString('base64')),
+    'input map as inlined data URI with charset utf-8, base64': inlineDataUriContext('data:application/json;charset=utf-8;base64,' + Buffer.from(inputMap, 'utf8').toString('base64')),
+    'input map as inlined data URI with charset utf-8, not base64': inlineDataUriContext('data:application/json;charset=utf-8,' + escape(String.fromCharCode.apply(String, Buffer.from(inputMap, 'utf8')))),
+    'input map as inlined data URI with explicit charset us-ascii, base64': inlineDataUriContext('data:application/json;charset=us-ascii;base64,' + Buffer.from(inputMap, 'ascii').toString('base64')),
     'input map as inlined data URI with explicit charset us-ascii, not base64': inlineDataUriContext('data:application/json;charset=us-ascii,' + escape(inputMap)),
     'complex input map': {
       'topic': function () {
-        return new CleanCSS({ level: 2, sourceMap: true }).minify('@import url(' + path.dirname(inputMapPath) + '/import.css);');
+        return new CleanCSS({ level: 2, rebase: true, sourceMap: true }).minify('@import url(' + path.dirname(inputMapPath) + '/import.css);');
       },
       'has 6 mappings': function (minified) {
         assert.lengthOf(minified.sourceMap._mappings._array, 6);
@@ -731,7 +750,7 @@ vows.describe('source-map')
     },
     'complex but partial input map referenced by path': {
       'topic': function () {
-        return new CleanCSS({ level: 2, sourceMap: true }).minify('@import url(test/fixtures/source-maps/no-map-import.css);');
+        return new CleanCSS({ level: 2, rebase: true, sourceMap: true }).minify('@import url(test/fixtures/source-maps/no-map-import.css);');
       },
       'has 6 mappings': function (minified) {
         assert.lengthOf(minified.sourceMap._mappings._array, 6);
@@ -751,7 +770,7 @@ vows.describe('source-map')
     },
     'complex input map with an existing file as rebaseTo': {
       'topic': function () {
-        return new CleanCSS({ level: 2, sourceMap: true, rebaseTo: path.join('test', 'fixtures', 'source-maps') }).minify('@import url(test/fixtures/source-maps/styles.css);');
+        return new CleanCSS({ level: 2, sourceMap: true, rebase: true, rebaseTo: path.join('test', 'fixtures', 'source-maps') }).minify('@import url(test/fixtures/source-maps/styles.css);');
       },
       'has 3 mappings': function (minified) {
         assert.lengthOf(minified.sourceMap._mappings._array, 3);
@@ -765,7 +784,7 @@ vows.describe('source-map')
     },
     'nested once': {
       'topic': function () {
-        return new CleanCSS({ level: 2, sourceMap: true }).minify('@import url(test/fixtures/source-maps/nested/once.css);');
+        return new CleanCSS({ level: 2, rebase: true, sourceMap: true }).minify('@import url(test/fixtures/source-maps/nested/once.css);');
       },
       'has 3 mappings': function (minified) {
         assert.lengthOf(minified.sourceMap._mappings._array, 3);
@@ -806,7 +825,7 @@ vows.describe('source-map')
     },
     'nested twice': {
       'topic': function () {
-        return new CleanCSS({ level: 2, sourceMap: true }).minify('@import url(test/fixtures/source-maps/nested/twice.css);');
+        return new CleanCSS({ level: 2, rebase: true, sourceMap: true }).minify('@import url(test/fixtures/source-maps/nested/twice.css);');
       },
       'has 3 mappings': function (minified) {
         assert.lengthOf(minified.sourceMap._mappings._array, 3);
@@ -1095,7 +1114,7 @@ vows.describe('source-map')
           .get('/remote.css.map')
           .reply(200, inputMap);
 
-        new CleanCSS({ inline: 'all', sourceMap: true }).minify('@import url(http://127.0.0.1/remote.css);', this.callback);
+        new CleanCSS({ inline: 'all', rebase: true, sourceMap: true }).minify('@import url(http://127.0.0.1/remote.css);', this.callback);
       },
       'has mapping': function (errors, minified) {
         assert.isDefined(minified.sourceMap);
@@ -1132,7 +1151,7 @@ vows.describe('source-map')
           .post('/remote.css.map')
           .reply(200, inputMap);
 
-        new CleanCSS({ inline: 'all', inlineRequest: { method: 'POST' }, sourceMap: true })
+        new CleanCSS({ inline: 'all', inlineRequest: { method: 'POST' }, rebase: true, sourceMap: true })
           .minify('@import url(http://127.0.0.1/remote.css);', this.callback);
       },
       'has mapping': function (errors, minified) {
@@ -1645,7 +1664,7 @@ vows.describe('source-map')
       },
       'multiple relative to rebaseTo path': {
         'topic': function () {
-          return new CleanCSS({ level: 2, sourceMap: true, sourceMapInlineSources: true, rebaseTo: './test' }).minify({
+          return new CleanCSS({ level: 2, sourceMap: true, sourceMapInlineSources: true, rebase: true, rebaseTo: './test' }).minify({
             'test/fixtures/source-maps/some.css': {
               styles: 'div {\n  color: red;\n}',
               sourceMap: '{"version":3,"sources":["some.less"],"names":[],"mappings":"AAAA;EACE,UAAA","file":"some.css","sourcesContent":["div {\\n  color: red;\\n}\\n"]}'
